[SCM] WebKit Debian packaging branch, webkit-1.2, updated. upstream/1.1.90-6072-g9a69373

abarth at webkit.org abarth at webkit.org
Thu Apr 8 00:56:50 UTC 2010


The following commit has been merged in the webkit-1.2 branch:
commit ccdbe3aa964337c600b35560e93f616eeb35bf05
Author: abarth at webkit.org <abarth at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Thu Jan 7 08:49:25 2010 +0000

    2010-01-07  Adam Barth  <abarth at webkit.org>
    
            Reviewed by Eric Seidel.
    
            bugzilla-tool needs a new name
            https://bugs.webkit.org/show_bug.cgi?id=28459
    
            Rename bugzilla-tool to webkit-patch.  Also, rename some commands to
            make more sense with the new name.
    
            * Scripts/bugzilla-tool: Removed.
            * Scripts/webkit-patch: Added.
            * Scripts/webkit-tools-completion.sh:
            * Scripts/webkitpy/bugzilla_unittest.py:
            * Scripts/webkitpy/commands/download.py:
            * Scripts/webkitpy/commands/download_unittest.py:
            * Scripts/webkitpy/commands/early_warning_system.py:
            * Scripts/webkitpy/commands/queries.py:
            * Scripts/webkitpy/commands/queues.py:
            * Scripts/webkitpy/commands/queues_unittest.py:
            * Scripts/webkitpy/commands/upload.py:
            * Scripts/webkitpy/commands/upload_unittest.py:
            * Scripts/webkitpy/queueengine.py:
            * Scripts/webkitpy/steps/completerollout.py:
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@52907 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKitTools/ChangeLog b/WebKitTools/ChangeLog
index da7f72c..c60c221 100644
--- a/WebKitTools/ChangeLog
+++ b/WebKitTools/ChangeLog
@@ -1,3 +1,28 @@
+2010-01-07  Adam Barth  <abarth at webkit.org>
+
+        Reviewed by Eric Seidel.
+
+        bugzilla-tool needs a new name
+        https://bugs.webkit.org/show_bug.cgi?id=28459
+
+        Rename bugzilla-tool to webkit-patch.  Also, rename some commands to
+        make more sense with the new name.
+
+        * Scripts/bugzilla-tool: Removed.
+        * Scripts/webkit-patch: Added.
+        * Scripts/webkit-tools-completion.sh:
+        * Scripts/webkitpy/bugzilla_unittest.py:
+        * Scripts/webkitpy/commands/download.py:
+        * Scripts/webkitpy/commands/download_unittest.py:
+        * Scripts/webkitpy/commands/early_warning_system.py:
+        * Scripts/webkitpy/commands/queries.py:
+        * Scripts/webkitpy/commands/queues.py:
+        * Scripts/webkitpy/commands/queues_unittest.py:
+        * Scripts/webkitpy/commands/upload.py:
+        * Scripts/webkitpy/commands/upload_unittest.py:
+        * Scripts/webkitpy/queueengine.py:
+        * Scripts/webkitpy/steps/completerollout.py:
+
 2010-01-07  Chris Jerdonek  <chris.jerdonek at gmail.com>
 
         Reviewed by Eric Seidel.
diff --git a/WebKitTools/Scripts/bugzilla-tool b/WebKitTools/Scripts/bugzilla-tool
deleted file mode 100755
index adc66c6..0000000
--- a/WebKitTools/Scripts/bugzilla-tool
+++ /dev/null
@@ -1,108 +0,0 @@
-#!/usr/bin/env python
-# Copyright (c) 2009, Google Inc. All rights reserved.
-# Copyright (c) 2009 Apple Inc. All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-#     * Redistributions of source code must retain the above copyright
-# notice, this list of conditions and the following disclaimer.
-#     * Redistributions in binary form must reproduce the above
-# copyright notice, this list of conditions and the following disclaimer
-# in the documentation and/or other materials provided with the
-# distribution.
-#     * Neither the name of Google Inc. nor the names of its
-# contributors may be used to endorse or promote products derived from
-# this software without specific prior written permission.
-# 
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# A tool for automating dealing with bugzilla, posting patches, committing patches, etc.
-
-import os
-
-from webkitpy.bugzilla import Bugzilla
-from webkitpy.buildbot import BuildBot
-from webkitpy.commands.download import *
-from webkitpy.commands.early_warning_system import *
-from webkitpy.commands.queries import *
-from webkitpy.commands.queues import *
-from webkitpy.commands.upload import *
-from webkitpy.executive import Executive
-from webkitpy.webkit_logging import log
-from webkitpy.multicommandtool import MultiCommandTool
-from webkitpy.scm import detect_scm_system
-from webkitpy.user import User
-
-
-class BugzillaTool(MultiCommandTool):
-    global_options = [
-        make_option("--dry-run", action="store_true", dest="dry_run", default=False, help="do not touch remote servers"),
-        make_option("--status-host", action="store", dest="status_host", type="string", nargs=1, help="Hostname (e.g. localhost or commit.webkit.org) where status updates should be posted."),
-    ]
-
-    def __init__(self):
-        MultiCommandTool.__init__(self)
-
-        self.bugs = Bugzilla()
-        self.buildbot = BuildBot()
-        self.executive = Executive()
-        self.user = User()
-        self._scm = None
-        self.status_server = StatusServer()
-
-    def scm(self):
-        # Lazily initialize SCM to not error-out before command line parsing (or when running non-scm commands).
-        original_cwd = os.path.abspath(".")
-        if not self._scm:
-            self._scm = detect_scm_system(original_cwd)
-
-        if not self._scm:
-            script_directory = os.path.abspath(sys.path[0])
-            webkit_directory = os.path.abspath(os.path.join(script_directory, "../.."))
-            self._scm = detect_scm_system(webkit_directory)
-            if self._scm:
-                log("The current directory (%s) is not a WebKit checkout, using %s" % (original_cwd, webkit_directory))
-            else:
-                error("FATAL: Failed to determine the SCM system for either %s or %s" % (original_cwd, webkit_directory))
-
-        return self._scm
-
-    def path(self):
-        return __file__
-
-    def should_show_in_main_help(self, command):
-        if not command.show_in_main_help:
-            return False
-        if command.requires_local_commits:
-            return self.scm().supports_local_commits()
-        return True
-
-    # FIXME: This may be unnecessary since we pass global options to all commands during execute() as well.
-    def handle_global_options(self, options):
-        if options.dry_run:
-            self.scm().dryrun = True
-            self.bugs.dryrun = True
-        if options.status_host:
-            self.status_server.set_host(options.status_host)
-
-    def should_execute_command(self, command):
-        if command.requires_local_commits and not self.scm().supports_local_commits():
-            failure_reason = "%s requires local commits using %s in %s." % (command.name, self.scm().display_name(), self.scm().checkout_root)
-            return (False, failure_reason)
-        return (True, None)
-
-
-if __name__ == "__main__":
-    BugzillaTool().main()
diff --git a/WebKitTools/Scripts/webkit-patch b/WebKitTools/Scripts/webkit-patch
new file mode 100755
index 0000000..46e8bff
--- /dev/null
+++ b/WebKitTools/Scripts/webkit-patch
@@ -0,0 +1,108 @@
+#!/usr/bin/env python
+# Copyright (c) 2009, Google Inc. All rights reserved.
+# Copyright (c) 2009 Apple Inc. All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are
+# met:
+# 
+#     * Redistributions of source code must retain the above copyright
+# notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above
+# copyright notice, this list of conditions and the following disclaimer
+# in the documentation and/or other materials provided with the
+# distribution.
+#     * Neither the name of Google Inc. nor the names of its
+# contributors may be used to endorse or promote products derived from
+# this software without specific prior written permission.
+# 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#
+# A tool for automating dealing with bugzilla, posting patches, committing patches, etc.
+
+import os
+
+from webkitpy.bugzilla import Bugzilla
+from webkitpy.buildbot import BuildBot
+from webkitpy.commands.download import *
+from webkitpy.commands.early_warning_system import *
+from webkitpy.commands.queries import *
+from webkitpy.commands.queues import *
+from webkitpy.commands.upload import *
+from webkitpy.executive import Executive
+from webkitpy.webkit_logging import log
+from webkitpy.multicommandtool import MultiCommandTool
+from webkitpy.scm import detect_scm_system
+from webkitpy.user import User
+
+
+class WebKitPatch(MultiCommandTool):
+    global_options = [
+        make_option("--dry-run", action="store_true", dest="dry_run", default=False, help="do not touch remote servers"),
+        make_option("--status-host", action="store", dest="status_host", type="string", nargs=1, help="Hostname (e.g. localhost or commit.webkit.org) where status updates should be posted."),
+    ]
+
+    def __init__(self):
+        MultiCommandTool.__init__(self)
+
+        self.bugs = Bugzilla()
+        self.buildbot = BuildBot()
+        self.executive = Executive()
+        self.user = User()
+        self._scm = None
+        self.status_server = StatusServer()
+
+    def scm(self):
+        # Lazily initialize SCM to not error-out before command line parsing (or when running non-scm commands).
+        original_cwd = os.path.abspath(".")
+        if not self._scm:
+            self._scm = detect_scm_system(original_cwd)
+
+        if not self._scm:
+            script_directory = os.path.abspath(sys.path[0])
+            webkit_directory = os.path.abspath(os.path.join(script_directory, "../.."))
+            self._scm = detect_scm_system(webkit_directory)
+            if self._scm:
+                log("The current directory (%s) is not a WebKit checkout, using %s" % (original_cwd, webkit_directory))
+            else:
+                error("FATAL: Failed to determine the SCM system for either %s or %s" % (original_cwd, webkit_directory))
+
+        return self._scm
+
+    def path(self):
+        return __file__
+
+    def should_show_in_main_help(self, command):
+        if not command.show_in_main_help:
+            return False
+        if command.requires_local_commits:
+            return self.scm().supports_local_commits()
+        return True
+
+    # FIXME: This may be unnecessary since we pass global options to all commands during execute() as well.
+    def handle_global_options(self, options):
+        if options.dry_run:
+            self.scm().dryrun = True
+            self.bugs.dryrun = True
+        if options.status_host:
+            self.status_server.set_host(options.status_host)
+
+    def should_execute_command(self, command):
+        if command.requires_local_commits and not self.scm().supports_local_commits():
+            failure_reason = "%s requires local commits using %s in %s." % (command.name, self.scm().display_name(), self.scm().checkout_root)
+            return (False, failure_reason)
+        return (True, None)
+
+
+if __name__ == "__main__":
+    WebKitPatch().main()
diff --git a/WebKitTools/Scripts/webkit-tools-completion.sh b/WebKitTools/Scripts/webkit-tools-completion.sh
index 308711d..5eb6833 100644
--- a/WebKitTools/Scripts/webkit-tools-completion.sh
+++ b/WebKitTools/Scripts/webkit-tools-completion.sh
@@ -32,12 +32,12 @@
 #   Add a line like this to your .bashrc:
 #     source /path/to/WebKitCode/WebKitTools/Scripts/webkit-tools-completion.sh
 
-__bugzilla-tool_generate_reply()
+__webkit-patch_generate_reply()
 {
     COMPREPLY=( $(compgen -W "$1" -- "${COMP_WORDS[COMP_CWORD]}") )
 }
 
-_bugzilla-tool_complete()
+_webkit-patch_complete()
 {
     local command current_command="${COMP_WORDS[1]}"
     case "$current_command" in
@@ -50,41 +50,45 @@ _bugzilla-tool_complete()
     esac
 
     if [ $COMP_CWORD -eq 1 ]; then
-        __bugzilla-tool_generate_reply "--help apply-patches bugs-to-commit commit-message land-diff land-patches obsolete-attachments patches-to-commit post-commits post-diff reviewed-patches"
+        __webkit-patch_generate_reply "--help apply-from-bug bugs-to-commit commit-message land land-from-bug obsolete-attachments patches-to-commit post upload tree-status rollout reviewed-patches"
         return
     fi
 
     case "$command" in
-        apply-patches)
-            __bugzilla-tool_generate_reply "--force-clean --local-commit --no-clean --no-update"
+        apply-from-bug)
+            __webkit-patch_generate_reply "--force-clean --local-commit --no-clean --no-update"
             return
             ;;
         commit-message)
             return
             ;;
-        land-diff)
-            __bugzilla-tool_generate_reply "--no-build --no-close --no-test --reviewer= -r"
+        land)
+            __webkit-patch_generate_reply "--no-build --no-close --no-test --reviewer= -r"
             return
             ;;
-        land-patches)
-            __bugzilla-tool_generate_reply "--force-clean --no-build --no-clean --no-test"
+        land-from-bug)
+            __webkit-patch_generate_reply "--force-clean --no-build --no-clean --no-test"
             return
             ;;
         obsolete-attachments)
             return
             ;;
-        post-diff)
-            __bugzilla-tool_generate_reply "--description --no-obsolete --no-review -m"
+        post)
+            __webkit-patch_generate_reply "--description --no-obsolete --no-review --request-commit -m --open-bug"
+            return
+            ;;
+        upload)
+            __webkit-patch_generate_reply "--description --no-obsolete --no-review --request-commit --cc -m --open-bug"
             return
             ;;
         post-commits)
-            __bugzilla-tool_generate_reply "--bug-id= --no-comment --no-obsolete --no-review -b"
+            __webkit-patch_generate_reply "--bug-id= --no-comment --no-obsolete --no-review -b"
             return
             ;;
     esac
 }
 
-complete -F _bugzilla-tool_complete bugzilla-tool
+complete -F _webkit-patch_complete webkit-patch
 complete -W "--continue --fix-merged --help --no-continue --no-warnings --warnings -c -f -h -w" resolve-ChangeLogs
 complete -W "--bug --diff --git-commit --git-index --git-reviewer --help --no-update --no-write --open --update --write -d -h -o" prepare-ChangeLog
 complete -W "--clean --debug --help -h" build-webkit
diff --git a/WebKitTools/Scripts/webkitpy/bugzilla_unittest.py b/WebKitTools/Scripts/webkitpy/bugzilla_unittest.py
index 93a35f9..0d78602 100644
--- a/WebKitTools/Scripts/webkitpy/bugzilla_unittest.py
+++ b/WebKitTools/Scripts/webkitpy/bugzilla_unittest.py
@@ -115,7 +115,7 @@ class BugzillaTest(unittest.TestCase):
     <bug>
           <bug_id>32585</bug_id>
           <creation_ts>2009-12-15 15:17 PST</creation_ts>
-          <short_desc>bug to test bugzilla-tool and commit-queue failures</short_desc>
+          <short_desc>bug to test webkit-patch and commit-queue failures</short_desc>
           <delta_ts>2009-12-27 21:04:50 PST</delta_ts>
           <reporter_accessible>1</reporter_accessible>
           <cclist_accessible>1</cclist_accessible>
@@ -138,9 +138,9 @@ class BugzillaTest(unittest.TestCase):
           <long_desc isprivate="0">
             <who name="Eric Seidel">eric at webkit.org</who>
             <bug_when>2009-12-15 15:17:28 PST</bug_when>
-            <thetext>bug to test bugzilla-tool and commit-queue failures
+            <thetext>bug to test webkit-patch and commit-queue failures
 
-Ignore this bug.  Just for testing failure modes of bugzilla-tool and the commit-queue.</thetext>
+Ignore this bug.  Just for testing failure modes of webkit-patch and the commit-queue.</thetext>
           </long_desc>
           <attachment 
               isobsolete="0"
@@ -172,7 +172,7 @@ ZEZpbmlzaExvYWRXaXRoUmVhc29uOnJlYXNvbl07Cit9CisKIEBlbmQKIAogI2VuZGlmCg==
 """
     _expected_example_bug_parsing = {
         "id" : 32585,
-        "title" : u"bug to test bugzilla-tool and commit-queue failures",
+        "title" : u"bug to test webkit-patch and commit-queue failures",
         "cc_emails" : ["foo at bar.com", "example at example.com"],
         "reporter_email" : "eric at webkit.org",
         "assigned_to_email" : "webkit-unassigned at lists.webkit.org",
diff --git a/WebKitTools/Scripts/webkitpy/commands/download.py b/WebKitTools/Scripts/webkitpy/commands/download.py
index 74b16c6..3f69af4 100644
--- a/WebKitTools/Scripts/webkitpy/commands/download.py
+++ b/WebKitTools/Scripts/webkitpy/commands/download.py
@@ -66,8 +66,8 @@ class BuildAndTest(AbstractSequencedCommmand):
     ]
 
 
-class LandDiff(AbstractSequencedCommmand):
-    name = "land-diff"
+class Land(AbstractSequencedCommmand):
+    name = "land"
     help_text = "Land the current working directory diff and updates the associated bug if any"
     argument_names = "[BUGID]"
     show_in_main_help = True
@@ -80,9 +80,9 @@ class LandDiff(AbstractSequencedCommmand):
         steps.Commit,
         steps.CloseBugForLandDiff,
     ]
-    long_help = """land-diff commits the current working copy diff (just as svn or git commit would).
-land-diff will build and run the tests before committing.
-If a bug id is provided, or one can be found in the ChangeLog land-diff will update the bug after committing."""
+    long_help = """land commits the current working copy diff (just as svn or git commit would).
+land will build and run the tests before committing.
+If a bug id is provided, or one can be found in the ChangeLog land will update the bug after committing."""
 
     def _prepare_state(self, options, args, tool):
         return {
@@ -198,8 +198,8 @@ class ApplyAttachment(AbstractPatchApplyingCommand, ProcessAttachmentsMixin):
     show_in_main_help = True
 
 
-class ApplyPatches(AbstractPatchApplyingCommand, ProcessBugsMixin):
-    name = "apply-patches"
+class ApplyFromBug(AbstractPatchApplyingCommand, ProcessBugsMixin):
+    name = "apply-from-bug"
     help_text = "Apply reviewed patches from provided bugs to the local working directory"
     argument_names = "BUGID [BUGIDS]"
     show_in_main_help = True
@@ -237,8 +237,8 @@ class LandAttachment(AbstractPatchLandingCommand, ProcessAttachmentsMixin):
     show_in_main_help = True
 
 
-class LandPatches(AbstractPatchLandingCommand, ProcessBugsMixin):
-    name = "land-patches"
+class LandFromBug(AbstractPatchLandingCommand, ProcessBugsMixin):
+    name = "land-from-bug"
     help_text = "Land all patches on the given bugs, optionally building and testing them first"
     argument_names = "BUGID [BUGIDS]"
     show_in_main_help = True
diff --git a/WebKitTools/Scripts/webkitpy/commands/download_unittest.py b/WebKitTools/Scripts/webkitpy/commands/download_unittest.py
index c9cd6d7..f2c7d9c 100644
--- a/WebKitTools/Scripts/webkitpy/commands/download_unittest.py
+++ b/WebKitTools/Scripts/webkitpy/commands/download_unittest.py
@@ -67,11 +67,11 @@ class DownloadCommandsTest(CommandsTest):
         options.update = True
         options.local_commit = True
         expected_stderr = "Updating working directory\n2 reviewed patches found on bug 42.\nProcessing 2 patches from 1 bug.\nProcessing patch 197 from bug 42.\nProcessing patch 128 from bug 42.\n"
-        self.assert_execute_outputs(ApplyPatches(), [42], options=options, expected_stderr=expected_stderr)
+        self.assert_execute_outputs(ApplyFromBug(), [42], options=options, expected_stderr=expected_stderr)
 
     def test_land_diff(self):
         expected_stderr = "Building WebKit\nUpdating bug 42\n"
-        self.assert_execute_outputs(LandDiff(), [42], options=self._default_options(), expected_stderr=expected_stderr)
+        self.assert_execute_outputs(Land(), [42], options=self._default_options(), expected_stderr=expected_stderr)
 
     def test_check_style(self):
         expected_stderr = "Processing 1 patch from 1 bug.\nUpdating working directory\nProcessing patch 197 from bug 42.\nRunning check-webkit-style\n"
@@ -87,10 +87,10 @@ class DownloadCommandsTest(CommandsTest):
 
     def test_land_patches(self):
         expected_stderr = "2 reviewed patches found on bug 42.\nProcessing 2 patches from 1 bug.\nUpdating working directory\nProcessing patch 197 from bug 42.\nBuilding WebKit\nUpdating working directory\nProcessing patch 128 from bug 42.\nBuilding WebKit\n"
-        self.assert_execute_outputs(LandPatches(), [42], options=self._default_options(), expected_stderr=expected_stderr)
+        self.assert_execute_outputs(LandFromBug(), [42], options=self._default_options(), expected_stderr=expected_stderr)
 
     def test_rollout(self):
-        expected_stderr = "Updating working directory\nRunning prepare-ChangeLog\n\nNOTE: Rollout support is experimental.\nPlease verify the rollout diff and use \"bugzilla-tool land-diff 12345\" to commit the rollout.\n"
+        expected_stderr = "Updating working directory\nRunning prepare-ChangeLog\n\nNOTE: Rollout support is experimental.\nPlease verify the rollout diff and use \"webkit-patch land 12345\" to commit the rollout.\n"
         self.assert_execute_outputs(Rollout(), [852, "Reason"], options=self._default_options(), expected_stderr=expected_stderr)
 
     def test_complete_rollout(self):
diff --git a/WebKitTools/Scripts/webkitpy/commands/early_warning_system.py b/WebKitTools/Scripts/webkitpy/commands/early_warning_system.py
index a5084ad..349cde1 100644
--- a/WebKitTools/Scripts/webkitpy/commands/early_warning_system.py
+++ b/WebKitTools/Scripts/webkitpy/commands/early_warning_system.py
@@ -42,7 +42,7 @@ class AbstractEarlyWarningSystem(AbstractReviewQueue):
 
     def should_proceed_with_work_item(self, patch):
         try:
-            self.run_bugzilla_tool(["build", self.port.flag(), "--force-clean", "--quiet"])
+            self.run_webkit_patch(["build", self.port.flag(), "--force-clean", "--quiet"])
             self._update_status("Building", patch)
         except ScriptError, e:
             self._update_status("Unable to perform a build")
@@ -51,7 +51,7 @@ class AbstractEarlyWarningSystem(AbstractReviewQueue):
 
     def process_work_item(self, patch):
         try:
-            self.run_bugzilla_tool([
+            self.run_webkit_patch([
                 "build-attachment",
                 self.port.flag(),
                 "--force-clean",
diff --git a/WebKitTools/Scripts/webkitpy/commands/queries.py b/WebKitTools/Scripts/webkitpy/commands/queries.py
index bc8b641..a5c5472 100644
--- a/WebKitTools/Scripts/webkitpy/commands/queries.py
+++ b/WebKitTools/Scripts/webkitpy/commands/queries.py
@@ -118,7 +118,6 @@ class ReviewedPatches(AbstractDeclarativeCommmand):
 
 class TreeStatus(AbstractDeclarativeCommmand):
     name = "tree-status"
-    show_in_main_help = True
     help_text = "Print the status of the %s buildbots" % BuildBot.default_host
     long_help = """Fetches build status from http://build.webkit.org/one_box_per_builder
 and displayes the status of each builder."""
diff --git a/WebKitTools/Scripts/webkitpy/commands/queues.py b/WebKitTools/Scripts/webkitpy/commands/queues.py
index 734fef3..7a9c580 100644
--- a/WebKitTools/Scripts/webkitpy/commands/queues.py
+++ b/WebKitTools/Scripts/webkitpy/commands/queues.py
@@ -106,12 +106,12 @@ class AbstractQueue(Command, QueueEngineDelegate):
     def handle_unexpected_error(self, work_item, message):
         raise NotImplementedError, "subclasses must implement"
 
-    def run_bugzilla_tool(self, args):
-        bugzilla_tool_args = [self.tool.path()]
+    def run_webkit_patch(self, args):
+        webkit_patch_args = [self.tool.path()]
         # FIXME: This is a hack, we should have a more general way to pass global options.
-        bugzilla_tool_args += ["--status-host=%s" % self.tool.status_server.host]
-        bugzilla_tool_args += map(str, args)
-        self.tool.executive.run_and_throw_if_fail(bugzilla_tool_args)
+        webkit_patch_args += ["--status-host=%s" % self.tool.status_server.host]
+        webkit_patch_args += map(str, args)
+        self.tool.executive.run_and_throw_if_fail(webkit_patch_args)
 
     def log_progress(self, patch_ids):
         log("%s in %s [%s]" % (pluralize("patch", len(patch_ids)), self.name, ", ".join(map(str, patch_ids))))
@@ -147,7 +147,7 @@ class CommitQueue(AbstractQueue, StepSequenceErrorHandler):
 
     def _can_build_and_test(self):
         try:
-            self.run_bugzilla_tool(["build-and-test", "--force-clean", "--non-interactive", "--build-style=both", "--quiet"])
+            self.run_webkit_patch(["build-and-test", "--force-clean", "--non-interactive", "--build-style=both", "--quiet"])
         except ScriptError, e:
             self._update_status("Unabled to successfully build and test", None)
             return False
@@ -177,7 +177,7 @@ class CommitQueue(AbstractQueue, StepSequenceErrorHandler):
             # We pass --no-update here because we've already validated
             # that the current revision actually builds and passes the tests.
             # If we update, we risk moving to a revision that doesn't!
-            self.run_bugzilla_tool(["land-attachment", "--force-clean", "--non-interactive", "--no-update", "--parent-command=commit-queue", "--build-style=both", "--quiet", patch["id"]])
+            self.run_webkit_patch(["land-attachment", "--force-clean", "--non-interactive", "--no-update", "--parent-command=commit-queue", "--build-style=both", "--quiet", patch["id"]])
             self._did_pass(patch)
         except ScriptError, e:
             self._did_fail(patch)
@@ -255,7 +255,7 @@ class StyleQueue(AbstractReviewQueue):
 
     def process_work_item(self, patch):
         try:
-            self.run_bugzilla_tool(["check-style", "--force-clean", "--non-interactive", "--parent-command=style-queue", patch["id"]])
+            self.run_webkit_patch(["check-style", "--force-clean", "--non-interactive", "--parent-command=style-queue", patch["id"]])
             message = "%s ran check-webkit-style on attachment %s without any errors." % (self.name, patch["id"])
             self.tool.bugs.post_comment_to_bug(patch["bug_id"], message, cc=self.watchers)
             self._did_pass(patch)
diff --git a/WebKitTools/Scripts/webkitpy/commands/queues_unittest.py b/WebKitTools/Scripts/webkitpy/commands/queues_unittest.py
index b985254..0c912f8 100644
--- a/WebKitTools/Scripts/webkitpy/commands/queues_unittest.py
+++ b/WebKitTools/Scripts/webkitpy/commands/queues_unittest.py
@@ -49,18 +49,18 @@ class AbstractQueueTest(CommandsTest):
         self._assert_log_progress_output(["1","2","3"], "3 patches in test-queue [1, 2, 3]\n")
         self._assert_log_progress_output([1], "1 patch in test-queue [1]\n")
 
-    def _assert_run_bugzilla_tool(self, run_args):
+    def _assert_run_webkit_patch(self, run_args):
         queue = TestQueue()
         tool = MockBugzillaTool()
         queue.bind_to_tool(tool)
 
-        queue.run_bugzilla_tool(run_args)
+        queue.run_webkit_patch(run_args)
         expected_run_args = ["echo", "--status-host=example.com"] + map(str, run_args)
         tool.executive.run_and_throw_if_fail.assert_called_with(expected_run_args)
 
-    def test_run_bugzilla_tool(self):
-        self._assert_run_bugzilla_tool([1])
-        self._assert_run_bugzilla_tool(["one", 2])
+    def test_run_webkit_patch(self):
+        self._assert_run_webkit_patch([1])
+        self._assert_run_webkit_patch(["one", 2])
 
 
 class CommitQueueTest(QueuesTest):
diff --git a/WebKitTools/Scripts/webkitpy/commands/upload_unittest.py b/WebKitTools/Scripts/webkitpy/commands/upload_unittest.py
index 217c2d2..627f60c 100644
--- a/WebKitTools/Scripts/webkitpy/commands/upload_unittest.py
+++ b/WebKitTools/Scripts/webkitpy/commands/upload_unittest.py
@@ -54,17 +54,17 @@ class UploadCommandsTest(CommandsTest):
 
     def test_post_diff(self):
         expected_stderr = "Obsoleting 2 old patches on bug 42\n"
-        self.assert_execute_outputs(PostDiff(), [42], expected_stderr=expected_stderr)
+        self.assert_execute_outputs(Post(), [42], expected_stderr=expected_stderr)
 
     def test_prepare_diff_with_arg(self):
-        self.assert_execute_outputs(PrepareDiff(), [42])
+        self.assert_execute_outputs(Prepare(), [42])
 
     def test_prepare_diff(self):
-        self.assert_execute_outputs(PrepareDiff(), [])
+        self.assert_execute_outputs(Prepare(), [])
 
     def test_submit_patch(self):
         expected_stderr = "Obsoleting 2 old patches on bug 42\n"
-        self.assert_execute_outputs(SubmitPatch(), [42], expected_stderr=expected_stderr)
+        self.assert_execute_outputs(Upload(), [42], expected_stderr=expected_stderr)
 
     def test_mark_bug_fixed(self):
         tool = MockBugzillaTool()
@@ -75,4 +75,4 @@ class UploadCommandsTest(CommandsTest):
         self.assert_execute_outputs(MarkBugFixed(), [], expected_stderr=expected_stderr, tool=tool, options=options)
 
     def test_edit_changelog(self):
-        self.assert_execute_outputs(EditChangeLog(), [])
+        self.assert_execute_outputs(EditChangeLogs(), [])
diff --git a/WebKitTools/Scripts/webkitpy/queueengine.py b/WebKitTools/Scripts/webkitpy/queueengine.py
index 59180ff..d14177d 100644
--- a/WebKitTools/Scripts/webkitpy/queueengine.py
+++ b/WebKitTools/Scripts/webkitpy/queueengine.py
@@ -107,7 +107,7 @@ class QueueEngine:
                     # handled in the child process and we should just keep looping.
                     if e.exit_code == self.handled_error_code:
                         continue
-                    message = "Unexpected failure when landing patch!  Please file a bug against bugzilla-tool.\n%s" % e.message_with_output()
+                    message = "Unexpected failure when landing patch!  Please file a bug against webkit-patch.\n%s" % e.message_with_output()
                     self._delegate.handle_unexpected_error(work_item, message)
             except KeyboardInterrupt, e:
                 log("\nUser terminated queue.")
diff --git a/WebKitTools/Scripts/webkitpy/steps/completerollout.py b/WebKitTools/Scripts/webkitpy/steps/completerollout.py
index 1dc52de..8534956 100644
--- a/WebKitTools/Scripts/webkitpy/steps/completerollout.py
+++ b/WebKitTools/Scripts/webkitpy/steps/completerollout.py
@@ -51,7 +51,7 @@ class CompleteRollout(MetaStep):
         # FIXME: Fully automated rollout is not 100% idiot-proof yet, so for now just log with instructions on how to complete the rollout.
         # Once we trust rollout we will remove this option.
         if not self._options.complete_rollout:
-            log("\nNOTE: Rollout support is experimental.\nPlease verify the rollout diff and use \"bugzilla-tool land-diff %s\" to commit the rollout." % bug_id)
+            log("\nNOTE: Rollout support is experimental.\nPlease verify the rollout diff and use \"webkit-patch land %s\" to commit the rollout." % bug_id)
             return
 
         MetaStep.run(self, state)

diff --git a/WebKitTools/Scripts/webkitpy/commands/upload.py b/WebKitTools/Scripts/webkitpy/commands/upload.py
index 7ca21b1..a689d55 100644
--- a/WebKitTools/Scripts/webkitpy/commands/upload.py
+++ b/WebKitTools/Scripts/webkitpy/commands/upload.py
@@ -109,11 +109,10 @@ class AbstractPatchUploadingCommand(AbstractSequencedCommmand):
         return bug_id
 
 
-class PostDiff(AbstractPatchUploadingCommand):
-    name = "post-diff"
+class Post(AbstractPatchUploadingCommand):
+    name = "post"
     help_text = "Attach the current working directory diff to a bug as a patch file"
     argument_names = "[BUGID]"
-    show_in_main_help = True
     steps = [
         steps.ConfirmDiff,
         steps.ObsoletePatches,
@@ -128,8 +127,8 @@ class PostDiff(AbstractPatchUploadingCommand):
         return state
 
 
-class PrepareDiff(AbstractSequencedCommmand):
-    name = "prepare-diff"
+class Prepare(AbstractSequencedCommmand):
+    name = "prepare"
     help_text = "Creates a bug (or prompts for an existing bug) and prepares the ChangeLogs"
     argument_names = "[BUGID]"
     steps = [
@@ -143,10 +142,11 @@ class PrepareDiff(AbstractSequencedCommmand):
         return { "bug_id" : bug_id }
 
 
-class SubmitPatch(AbstractPatchUploadingCommand):
-    name = "submit-patch"
+class Upload(AbstractPatchUploadingCommand):
+    name = "upload"
     help_text = "Automates the process of uploading a patch for review"
     argument_names = "[BUGID]"
+    show_in_main_help = True
     steps = [
         steps.PromptForBugOrTitle,
         steps.CreateBug,
@@ -156,10 +156,10 @@ class SubmitPatch(AbstractPatchUploadingCommand):
         steps.ObsoletePatches,
         steps.PostDiff,
     ]
-    long_help = """submit-patch uploads the current diff to bugs.webkit.org.
-    If no bug id is provided, submit-patch will create a bug.
-    If the current diff does not have a ChangeLog, submit-patch
-    will prepare a ChangeLog.  Once a patch is read, submit-patch
+    long_help = """upload uploads the current diff to bugs.webkit.org.
+    If no bug id is provided, upload will create a bug.
+    If the current diff does not have a ChangeLog, upload
+    will prepare a ChangeLog.  Once a patch is read, upload
     will open the ChangeLogs for editing using the command in the
     EDITOR environment variable and will display the diff using the
     command in the PAGER environment variable."""
@@ -170,9 +170,10 @@ class SubmitPatch(AbstractPatchUploadingCommand):
         return state
 
 
-class EditChangeLog(AbstractSequencedCommmand):
-    name = "edit-changelog"
+class EditChangeLogs(AbstractSequencedCommmand):
+    name = "edit-changelogs"
     help_text = "Opens modified ChangeLogs in $EDITOR"
+    show_in_main_help = True
     steps = [
         steps.EditChangeLog,
     ]
@@ -180,10 +181,9 @@ class EditChangeLog(AbstractSequencedCommmand):
 
 class PostCommits(AbstractDeclarativeCommmand):
     name = "post-commits"
-    show_in_main_help = True
     help_text = "Attach a range of local commits to bugs as patch files"
     argument_names = "COMMITISH"
-    
+
     def __init__(self):
         options = [
             make_option("-b", "--bug-id", action="store", type="string", dest="bug_id", help="Specify bug id if no URL is provided in the commit log."),
@@ -210,7 +210,7 @@ class PostCommits(AbstractDeclarativeCommmand):
     def execute(self, options, args, tool):
         commit_ids = tool.scm().commit_ids_from_commitish_arguments(args)
         if len(commit_ids) > 10: # We could lower this limit, 10 is too many for one bug as-is.
-            error("bugzilla-tool does not support attaching %s at once.  Are you sure you passed the right commit range?" % (pluralize("patch", len(commit_ids))))
+            error("webkit-patch does not support attaching %s at once.  Are you sure you passed the right commit range?" % (pluralize("patch", len(commit_ids))))
 
         have_obsoleted_patches = set()
         for commit_id in commit_ids:
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list